@@ -16,7 +16,7 @@ $ globus endpoint my-shared-endpoint-list $ep_id
 )
 @endpoint_id_arg
 @LoginManager.requires_login(LoginManager.TRANSFER_RS)
-def my_shared_endpoint_list(endpoint_id):
+def my_shared_endpoint_list(endpoint_id: str) -> None:
     """
     Show a list of all shared endpoints hosted on the target endpoint for which the user
     has the "administrator" or "access_manager" effective roles.
